==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/nl/generic.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "dit kwartaal",
	"field-quarter-short-relative+1": "volgend kwartaal",
	"field-tue-relative+-1": "afgelopen dinsdag",
	"field-year": "jaar",
	"dateFormatItem-Hm": "HH:mm",
	"field-wed-relative+0": "deze woensdag",
	"field-wed-relative+1": "volgende week woensdag",
	"dateFormatItem-ms": "mm:ss",
	"field-minute": "minuut",
	"field-month-narrow-relative+-1": "vorige maand",
	"field-tue-narrow-relative+0": "deze di",
	"field-tue-narrow-relative+1": "volgende week di",
	"field-day-short-relative+-1": "gisteren",
	"field-thu-short-relative+0": "deze donder.",
	"dateTimeFormat-short": "{1} {0}",
	"field-day-relative+0": "vandaag",
	"field-day-short-relative+-2": "eergisteren",
	"field-thu-short-relative+1": "volgende week donder.",
	"field-day-relative+1": "morgen",
	"field-week-narrow-relative+0": "deze week",
	"field-day-relative+2": "overmorgen",
	"field-week-narrow-relative+1": "volgende week",
	"field-wed-narrow-relative+-1": "afgelopen wo",
	"field-year-narrow": "jr",
	"field-year-narrow-relative+0": "dit jaar",
	"field-tue-relative+0": "deze dinsdag",
	"field-year-narrow-relative+1": "volgend jaar",
	"field-tue-relative+1": "volgende week dinsdag",
	"field-second-short": "sec",
	"dateFormatItem-MMMd": "d MMM",
	"field-week-relative+0": "deze week",
	"field-month-relative+0": "deze maand",
	"field-week-relative+1": "volgende week",
	"field-month-relative+1": "volgende maand",
	"field-sun-narrow-relative+0": "deze zo",
	"field-mon-short-relative+0": "deze maan.",
	"field-sun-narrow-relative+1": "volgende week zo",
	"field-mon-short-relative+1": "volgende week maan.",
	"field-second-relative+0": "nu",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"field-month-short": "mnd",
	"dateFormatItem-GyMMMEd": "E d MMM y G",
	"dateFormatItem-yyyyMd": "d-M-y GGGGG",
	"field-day": "dag",
	"field-year-relative+-1": "vorig jaar",
	"field-sat-short-relative+-1": "afgelopen zater.",
	"field-hour-relative+0": "binnen een uur",
	"dateFormatItem-yyyyMEd": "E d-M-y GGGGG",
	"field-second-short-relative+0": "nu",
	"field-wed-relative+-1": "afgelopen woensdag",
	"dateTimeFormat-medium": "{1} {0}",
	"field-sat-narrow-relative+-1": "afgelopen za",
	"field-second": "seconde",
	"dateFormat-long": "d MMMM y G",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-quarter": "kwartaal",
	"field-week-short": "wk",
	"field-day-narrow-relative+0": "vandaag",
	"field-day-narrow-relative+1": "morgen",
	"field-day-narrow-relative+2": "overmorgen",
	"field-tue-short-relative+0": "deze dins.",
	"field-tue-short-relative+1": "volgende week dins.",
	"field-month-short-relative+-1": "vorige maand",
	"field-mon-relative+-1": "afgelopen maandag",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-month": "maand",
	"field-day-narrow": "dag",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "min",
	"field-dayperiod": "dagdeel",
	"field-sat-short-relative+0": "deze zater.",
	"field-sat-short-relative+1": "volgende week zater.",
	"dateFormat-medium": "d MMM y G",
	"dateFormatItem-yyyyMMMM": "MMMM y G",
	"dateFormatItem-yyyyM": "M-y GGGGG",
	"field-second-narrow": "s",
	"field-mon-relative+0": "deze maandag",
	"field-mon-relative+1": "volgende week maandag",
	"field-day-narrow-relative+-1": "gisteren",
	"field-year-short": "jr",
	"field-day-narrow-relative+-2": "eergisteren",
	"field-quarter-relative+-1": "vorig kwartaal",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"field-week-narrow-relative+-1": "vorige week",
	"field-sat-relative+-1": "afgelopen zaterdag",
	"dateTimeFormat-long": "{1} 'om' {0}",
	"dateFormatItem-Md": "d-M",
	"field-hour": "uur",
	"dateFormat-full": "EEEE d MMMM y G",
	"field-month-relative+-1": "vorige maand",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-quarter-short": "kwartaal",
	"field-sat-narrow-relative+0": "deze za",
	"field-fri-relative+0": "deze vrijdag",
	"field-sat-narrow-relative+1": "volgende week za",
	"field-fri-relative+1": "volgende week vrijdag",
	"field-month-narrow-relative+0": "deze maand",
	"field-month-narrow-relative+1": "volgende maand",
	"field-sun-short-relative+0": "deze zon.",
	"field-sun-short-relative+1": "volgende week zon.",
	"field-week-relative+-1": "vorige week",
	"field-quarter-short-relative+-1": "vorig kwartaal",
	"field-quarter-relative+0": "dit kwartaal",
	"field-minute-relative+0": "binnen een minuut",
	"field-quarter-relative+1": "volgend kwartaal",
	"field-wed-short-relative+-1": "afgelopen woens.",
	"dateFormat-short": "dd-MM-yy GGGGG",
	"field-year-narrow-relative+-1": "vorig jaar",
	"field-thu-short-relative+-1": "afgelopen donder.",
	"dateFormatItem-yyyyMMMEd": "E d MMM y G",
	"field-mon-narrow-relative+-1": "afgelopen ma",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-thu-narrow-relative+-1": "afgelopen do",
	"dateFormatItem-E": "ccc",
	"field-tue-narrow-relative+-1": "afgelopen di",
	"dateFormatItem-H": "HH",
	"dateFormatItem-yyyy": "y G",
	"field-wed-short-relative+0": "deze woens.",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+1": "volgende week woens.",
	"field-sun-relative+-1": "afgelopen zondag",
	"dateTimeFormat-full": "{1} 'om' {0}",
	"field-second-narrow-relative+0": "nu",
	"dateFormatItem-hm": "h:mm a",
	"dateFormatItem-d": "d",
	"field-weekday": "dag van de week",
	"field-day-short-relative+0": "vandaag",
	"field-quarter-narrow-relative+0": "dit kwartaal",
	"field-day-short-relative+1": "morgen",
	"field-sat-relative+0": "deze zaterdag",
	"field-quarter-narrow-relative+1": "volgend kwartaal",
	"dateFormatItem-h": "h a",
	"field-day-short-relative+2": "overmorgen",
	"field-sat-relative+1": "volgende week zaterdag",
	"field-week-short-relative+0": "deze week",
	"field-week-short-relative+1": "volgende week",
	"field-month-short-relative+0": "deze maand",
	"field-month-short-relative+1": "volgende maand",
	"dateFormatItem-MEd": "E d-M",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "deze do",
	"field-sun-narrow-relative+-1": "afgelopen zo",
	"field-mon-short-relative+-1": "afgelopen maan.",
	"field-thu-narrow-relative+1": "volgende week do",
	"field-thu-relative+0": "deze donderdag",
	"field-thu-relative+1": "volgende week donderdag",
	"dateFormatItem-hms": "h:mm:ss a",
	"field-fri-short-relative+-1": "afgelopen vrij.",
	"field-thu-relative+-1": "afgelopen donderdag",
	"field-week": "week",
	"dateFormatItem-Ed": "E d",
	"field-wed-narrow-relative+0": "deze wo",
	"field-wed-narrow-relative+1": "volgende week wo",
	"field-quarter-narrow-relative+-1": "vorig kwartaal",
	"field-year-short-relative+0": "dit jaar",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"field-year-short-relative+1": "volgend jaar",
	"field-fri-short-relative+0": "deze vrij.",
	"field-fri-short-relative+1": "volgende week vrij.",
	"field-week-short-relative+-1": "vorige week",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "uur",
	"field-month-narrow": "mnd",
	"field-hour-narrow": "uur",
	"field-fri-narrow-relative+-1": "afgelopen vr",
	"field-year-relative+0": "dit jaar",
	"field-year-relative+1": "volgend jaar",
	"field-fri-relative+-1": "afgelopen vrijdag",
	"field-tue-short-relative+-1": "afgelopen dins.",
	"field-minute-narrow": "min",
	"field-mon-narrow-relative+0": "deze ma",
	"field-mon-narrow-relative+1": "volgende week ma",
	"field-year-short-relative+-1": "vorig jaar",
	"field-zone": "tijdzone",
	"dateFormatItem-MMMEd": "E d MMM",
	"field-quarter-narrow": "kwartaal",
	"field-sun-short-relative+-1": "afgelopen zon.",
	"field-day-relative+-1": "gisteren",
	"field-day-relative+-2": "eergisteren",
	"field-sun-relative+0": "deze zondag",
	"field-sun-relative+1": "volgende week zondag",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "dag",
	"field-week-narrow": "wk",
	"field-era": "tijdperk",
	"field-fri-narrow-relative+0": "deze vr",
	"field-fri-narrow-relative+1": "volgende week vr"
}
//end v1.x content
);

==> dojo_1.17.3+dfsg1.orig.tar.xz: dojo-release-1.17.3-src/dojo/cldr/nls/nl/generic.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "dit kwartaal",
	"field-quarter-short-relative+1": "volgend kwartaal",
	"field-tue-relative+-1": "afgelopen dinsdag",
	"field-year": "jaar",
	"dateFormatItem-Hm": "HH:mm",
	"field-wed-relative+0": "deze woensdag",
	"field-wed-relative+1": "volgende week woensdag",
	"dateFormatItem-ms": "mm:ss",
	"field-minute": "minuut",
	"field-month-narrow-relative+-1": "vorige maand",
	"field-tue-narrow-relative+0": "deze di",
	"field-tue-narrow-relative+1": "volgende week di",
	"field-day-short-relative+-1": "gisteren",
	"field-thu-short-relative+0": "deze donder.",
	"dateTimeFormat-short": "{1} {0}",
	"field-day-relative+0": "vandaag",
	"field-day-short-relative+-2": "eergisteren",
	"field-thu-short-relative+1": "volgende week donder.",
	"field-day-relative+1": "morgen",
	"field-week-narrow-relative+0": "deze week",
	"field-day-relative+2": "overmorgen",
	"field-week-narrow-relative+1": "volgende week",
	"dateFormatItem-EBhms": "E h:mm:ss B",
	"field-wed-narrow-relative+-1": "afgelopen wo",
	"field-year-narrow": "jr",
	"field-era-short": "tijdperk",
	"field-year-narrow-relative+0": "dit jaar",
	"field-tue-relative+0": "deze dinsdag",
	"field-year-narrow-relative+1": "volgend jaar",
	"field-tue-relative+1": "volgende week dinsdag",
	"field-weekdayOfMonth": "weekdag van de maand",
	"field-second-short": "sec",
	"dateFormatItem-MMMd": "d MMM",
	"field-weekdayOfMonth-narrow": "wkdag v.d. mnd",
	"field-week-relative+0": "deze week",
	"field-month-relative+0": "deze maand",
	"field-week-relative+1": "volgende week",
	"field-month-relative+1": "volgende maand",
	"field-sun-narrow-relative+0": "deze zo",
	"field-mon-short-relative+0": "deze maan.",
	"field-sun-narrow-relative+1": "volgende week zo",
	"field-mon-short-relative+1": "volgende week maan.",
	"field-second-relative+0": "nu",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"field-weekOfMonth": "week van de maand",
	"field-month-short": "mnd",
	"dateFormatItem-GyMMMEd": "E d MMM y G",
	"dateFormatItem-yyyyMd": "d-M-y GGGGG",
	"field-day": "dag",
	"field-dayOfYear-short": "dag van het jr",
	"field-year-relative+-1": "vorig jaar",
	"field-sat-short-relative+-1": "afgelopen zater.",
	"field-hour-relative+0": "binnen een uur",
	"dateFormatItem-yyyyMEd": "E d-M-y GGGGG",
	"field-second-short-relative+0": "nu",
	"field-wed-relative+-1": "afgelopen woensdag",
	"dateTimeFormat-medium": "{1} {0}",
	"field-sat-narrow-relative+-1": "afgelopen za",
	"field-second": "seconde",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"dateFormat-long": "d MMMM y G",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-hour-short-relative+0": "binnen een uur",
	"field-quarter": "kwartaal",
	"field-week-short": "wk",
	"field-day-narrow-relative+0": "vandaag",
	"field-day-narrow-relative+1": "morgen",
	"field-day-narrow-relative+2": "overmorgen",
	"field-tue-short-relative+0": "deze dins.",
	"field-tue-short-relative+1": "volgende week dins.",
	"field-month-short-relative+-1": "vorige maand",
	"field-mon-relative+-1": "afgelopen maandag",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-month": "maand",
	"field-day-narrow": "dag",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "min",
	"field-dayperiod": "a.m./p.m.",
	"field-sat-short-relative+0": "deze zater.",
	"field-sat-short-relative+1": "volgende week zater.",
	"dateFormat-medium": "d MMM y G",
	"dateFormatItem-yyyyMMMM": "MMMM y G",
	"dateFormatItem-yyyyM": "M-y GGGGG",
	"field-second-narrow": "s",
	"field-mon-relative+0": "deze maandag",
	"field-mon-relative+1": "volgende week maandag",
	"field-day-narrow-relative+-1": "gisteren",
	"field-year-short": "jr",
	"field-day-narrow-relative+-2": "eergisteren",
	"field-quarter-relative+-1": "vorig kwartaal",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"field-dayperiod-narrow": "a.m./p.m.",
	"field-week-narrow-relative+-1": "vorige week",
	"field-dayOfYear": "dag van het jaar",
	"field-sat-relative+-1": "afgelopen zaterdag",
	"dateTimeFormat-long": "{1} 'om' {0}",
	"dateFormatItem-Md": "d-M",
	"field-hour": "uur",
	"field-minute-narrow-relative+0": "binnen een minuut",
	"dateFormat-full": "EEEE d MMMM y G",
	"field-month-relative+-1": "vorige maand",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-quarter-short": "kwartaal",
	"field-sat-narrow-relative+0": "deze za",
	"field-fri-relative+0": "deze vrijdag",
	"field-sat-narrow-relative+1": "volgende week za",
	"field-fri-relative+1": "volgende week vrijdag",
	"dateFormatItem-EBhm": "E h:mm B",
	"field-month-narrow-relative+0": "deze maand",
	"field-month-narrow-relative+1": "volgende maand",
	"field-sun-short-relative+0": "deze zon.",
	"field-sun-short-relative+1": "volgende week zon.",
	"field-week-relative+-1": "vorige week",
	"field-quarter-short-relative+-1": "vorig kwartaal",
	"dateFormatItem-Ehm": "E h:mm a",
	"field-minute-short-relative+0": "binnen een minuut",
	"field-quarter-relative+0": "dit kwartaal",
	"field-minute-relative+0": "binnen een minuut",
	"field-quarter-relative+1": "volgend kwartaal",
	"field-wed-short-relative+-1": "afgelopen woens.",
	"dateFormat-short": "dd-MM-yy GGGGG",
	"dateFormatItem-Bh": "h B",
	"field-year-narrow-relative+-1": "vorig jaar",
	"field-thu-short-relative+-1": "afgelopen donder.",
	"dateFormatItem-yyyyMMMEd": "E d MMM y G",
	"field-mon-narrow-relative+-1": "afgelopen ma",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-thu-narrow-relative+-1": "afgelopen do",
	"dateFormatItem-E": "ccc",
	"dateFormatItem-H": "HH",
	"field-weekOfMonth-short": "wk van de mnd",
	"field-tue-narrow-relative+-1": "afgelopen di",
	"dateFormatItem-yyyy": "y G",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+0": "deze woens.",
	"field-wed-short-relative+1": "volgende week woens.",
	"field-sun-relative+-1": "afgelopen zondag",
	"dateTimeFormat-full": "{1} 'om' {0}",
	"field-second-narrow-relative+0": "nu",
	"dateFormatItem-hm": "h:mm a",
	"dateFormatItem-d": "d",
	"field-weekday": "dag van de week",
	"field-day-short-relative+0": "vandaag",
	"field-quarter-narrow-relative+0": "dit kwartaal",
	"field-day-short-relative+1": "morgen",
	"field-sat-relative+0": "deze zaterdag",
	"field-quarter-narrow-relative+1": "volgend kwartaal",
	"dateFormatItem-h": "h a",
	"field-day-short-relative+2": "overmorgen",
	"field-sat-relative+1": "volgende week zaterdag",
	"field-week-short-relative+0": "deze week",
	"field-week-short-relative+1": "volgende week",
	"field-dayOfYear-narrow": "dag v.h. jr",
	"field-month-short-relative+0": "deze maand",
	"field-month-short-relative+1": "volgende maand",
	"field-weekdayOfMonth-short": "wkdag van de mnd",
	"dateFormatItem-MEd": "E d-M",
	"field-zone-narrow": "zone",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "deze do",
	"field-sun-narrow-relative+-1": "afgelopen zo",
	"field-mon-short-relative+-1": "afgelopen maan.",
	"field-thu-narrow-relative+1": "volgende week do",
	"field-thu-relative+0": "deze donderdag",
	"field-thu-relative+1": "volgende week donderdag",
	"dateFormatItem-hms": "h:mm:ss a",
	"field-fri-short-relative+-1": "afgelopen vrij.",
	"field-thu-relative+-1": "afgelopen donderdag",
	"field-week": "week",
	"dateFormatItem-Ed": "E d",
	"field-wed-narrow-relative+0": "deze wo",
	"field-wed-narrow-relative+1": "volgende week wo",
	"field-quarter-narrow-relative+-1": "vorig kwartaal",
	"field-year-short-relative+0": "dit jaar",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"field-dayperiod-short": "a.m./p.m.",
	"field-year-short-relative+1": "volgend jaar",
	"field-fri-short-relative+0": "deze vrij.",
	"field-fri-short-relative+1": "volgende week vrij.",
	"field-week-short-relative+-1": "vorige week",
	"field-hour-narrow-relative+0": "binnen een uur",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "uur",
	"field-zone-short": "zone",
	"field-month-narrow": "mnd",
	"field-hour-narrow": "u",
	"field-fri-narrow-relative+-1": "afgelopen vr",
	"field-year-relative+0": "dit jaar",
	"field-year-relative+1": "volgend jaar",
	"field-era-narrow": "tijdperk",
	"field-fri-relative+-1": "afgelopen vrijdag",
	"dateFormatItem-Bhms": "h:mm:ss B",
	"field-tue-short-relative+-1": "afgelopen dins.",
	"field-minute-narrow": "min",
	"field-mon-narrow-relative+0": "deze ma",
	"dateFormatItem-EHm": "E HH:mm",
	"field-mon-narrow-relative+1": "volgende week ma",
	"field-year-short-relative+-1": "vorig jaar",
	"field-zone": "tijdzone",
	"dateFormatItem-MMMEd": "E d MMM",
	"field-weekOfMonth-narrow": "wk v.d. mnd",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"field-weekday-narrow": "dag v.d. wk",
	"field-quarter-narrow": "kwartaal",
	"field-sun-short-relative+-1": "afgelopen zon.",
	"field-day-relative+-1": "gisteren",
	"field-day-relative+-2": "eergisteren",
	"field-weekday-short": "dag van de wk",
	"dateFormatItem-Bhm": "h:mm B",
	"field-sun-relative+0": "deze zondag",
	"field-sun-relative+1": "volgende week zondag",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "dag",
	"field-week-narrow": "wk",
	"field-era": "tijdperk",
	"field-fri-narrow-relative+0": "deze vr",
	"field-fri-narrow-relative+1": "volgende week vr"
}
//end v1.x content
);
